### Name: MLDA-package
### Title: Methylation Linear Discriminant Analysis (MLDA)
### Aliases: MLDA-package MLDA
### Keywords: package

### ** Examples

                
data(hcgi12k)
i<-c(1,2,5,6)

##construct dataset
dataset<-mlda.data(dig1=hcgi12k$G[,i],undig1=hcgi12k$R[,i],dig2=hcgi12k$Rds[,i],
undig2=hcgi12k$Gds[,i],unmeth.flag=hcgi12k$mito.flag,cl=hcgi12k$cl[i],
sample.names=hcgi12k$sample.names[i],flag1=hcgi12k$flag[,i],flag2=hcgi12k$flagds[,i])

##Transform the log ratios of features to log likelihood ratios
mlda.result<-mlda(dataset,norm=FALSE,trim=0.05)

##Determie the cut-offs of log likelihood ratios for methylation and unmethylation 
##on dye-swapped/duplicate arrays
mytest<-cutoff(dataset,mlda.result,ncut=10)

##Select the optimal IR and CR             
cutoff.plot(dataset,mytest)

##Score the features and construct the robust regression model using the averaged 
##scores in two classes of samples.
##Determied the outliers (positive and negative) of the model.    
myscore<-score.cal(mlda.result,mytest,dataset,perm=50)

##Report the analysis result
result<-mlda.sig(score.obj=myscore,dataset,pvalue=0.05,loci.ID=rownames(dataset$R))

##Check the interestig loci on the plot of log likelihood ratios
lr.plot(dataset,mlda.result,mytest,loci=c("119_A_6","66_G_6"),legend=TRUE)

##Visualise the analysis result
mlda.sig.plot(myscore,control1=dataset$mito.flag)



